@@ -9,24 +9,23 @@ from bokeh.core.properties import (
 )
 from bokeh.events import ModelEvent
 from bokeh.models import ColumnDataSource, LayoutDOM
-from bokeh.models.layouts import HTMLBox
 from bokeh.models.widgets.tables import TableColumn
 
 from ..config import config
-from ..io.resources import JS_VERSION, bundled_files
+from ..io.resources import bundled_files
 from ..util import classproperty
+from .layout import HTMLBox
 
-TABULATOR_VERSION = "5.3.2"
+TABULATOR_VERSION = "5.4.4"
 
 JS_SRC = f"{config.npm_cdn}/tabulator-tables@{TABULATOR_VERSION}/dist/js/tabulator.js"
 MOMENT_SRC = f"{config.npm_cdn}/luxon/build/global/luxon.min.js"
 
 THEME_PATH = f"tabulator-tables@{TABULATOR_VERSION}/dist/css/"
 THEME_URL = f"{config.npm_cdn}/{THEME_PATH}"
-PANEL_CDN = f"{config.npm_cdn}/@holoviz/panel@{JS_VERSION}/dist/bundled/datatabulator/{THEME_PATH}"
 TABULATOR_THEMES = [
     'default', 'site', 'simple', 'midnight', 'modern', 'bootstrap',
-    'bootstrap4', 'materialize', 'bulma', 'semantic-ui', 'fast'
+    'bootstrap4', 'materialize', 'bulma', 'semantic-ui'
 ]
 # Theme names were renamed in Tabulator 5.0.
 _TABULATOR_THEMES_MAPPING = {
@@ -68,22 +67,15 @@ class CellClickEvent(ModelEvent):
             f'value={self.value})'
         )
 
-def _get_theme_url(url, theme):
-    if 'fast' in theme:
-        if url.startswith(THEME_URL):
-            url = url.replace(THEME_URL, PANEL_CDN)
-        url += 'fast/'
-    return url
 
 CSS_URLS = []
 for theme in TABULATOR_THEMES:
-    _url = _get_theme_url(THEME_URL, theme)
     if theme == 'default':
-        _url += 'tabulator.min.css'
+        _theme_file = 'tabulator.min.css'
     else:
         theme = _TABULATOR_THEMES_MAPPING.get(theme, theme)
-        _url += f'tabulator_{theme}.min.css'
-    CSS_URLS.append(_url)
+        _theme_file = f'tabulator_{theme}.min.css'
+    CSS_URLS.append(f'{THEME_URL}{_theme_file}')
 
 
 class DataTabulator(HTMLBox):
@@ -127,7 +119,7 @@ class DataTabulator(HTMLBox):
 
     source = Instance(ColumnDataSource)
 
-    styles = Dict(String, Either(String, Dict(Int, Dict(Int, List(Either(String, Tuple(String, String)))))))
+    cell_styles = Dict(String, Either(String, Dict(Int, Dict(Int, List(Either(String, Tuple(String, String)))))))
 
     pagination = Nullable(String)
 
@@ -143,10 +135,6 @@ class DataTabulator(HTMLBox):
 
     selectable_rows = Nullable(List(Int))
 
-    theme = Enum(*TABULATOR_THEMES, default="simple")
-
-    theme_url = String(default=THEME_URL)
-
     __css_raw__ = CSS_URLS
 
     @classproperty
