@@ -4,14 +4,15 @@ Defines custom VTKPlot bokeh model to render VTK objects.
 from bokeh.core.enums import enumeration
 from bokeh.core.has_props import abstract
 from bokeh.core.properties import (
-    Any, Bool, Dict, Enum, Float, Instance, Int, List, Nullable, Override,
-    PositiveInt, String,
+    Any, Bool, Bytes, Dict, Enum, Float, Instance, Int, List, Nullable,
+    Override, Positive, String,
 )
-from bokeh.models import ColorMapper, HTMLBox, Model
+from bokeh.models import ColorMapper, Model
 
 from ..config import config
 from ..io.resources import bundled_files
 from ..util import classproperty
+from .layout import HTMLBox
 
 vtk_cdn = f"{config.npm_cdn}/vtk.js@20.0.1/vtk.js"
 
@@ -24,7 +25,7 @@ class VTKAxes(Model):
 
     digits = Int(default=1)
 
-    fontsize = PositiveInt(default=12)
+    fontsize = Positive(Int, default=12)
 
     grid_opacity = Float(default=0.1)
 
@@ -86,7 +87,7 @@ class VTKSynchronizedPlot(AbstractVTKPlot):
     Bokeh model for plotting a VTK render window
     """
 
-    arrays = Dict(String, Any)
+    arrays = Dict(String, Bytes)
 
     arrays_processed = List(String)
 
