@@ -5,20 +5,20 @@ import sys
 
 from enum import Enum
 from typing import (
-    TYPE_CHECKING, ClassVar, List, Mapping, Optional,
+    TYPE_CHECKING, ClassVar, List, Mapping, Optional, Type,
 )
 
 import numpy as np
 import param
 
-from bokeh.models import ColumnDataSource
+from bokeh.models import ColumnDataSource, ImportedStyleSheet
 from pyviz_comms import JupyterComm
 
+from ..io.resources import CDN_DIST
 from ..reactive import ReactiveData
 from ..util import lazy_load
-from ..util.warnings import deprecated
 from ..viewable import Viewable
-from .base import PaneBase
+from .base import ModelPane
 
 if TYPE_CHECKING:
     from bokeh.document import Document
@@ -26,22 +26,10 @@ if TYPE_CHECKING:
     from pyviz_comms import Comm
 
 DEFAULT_THEME = "material"
-THEMES_MAP = {
-    "material": "perspective-viewer-material",
-    "material-dark": "perspective-viewer-material-dark",
-    "material-dense": "perspective-viewer-material-dense",
-    "material-dense-dark": "perspective-viewer-material-dense-dark",
-    "vaporwave": "perspective-viewer-vaporwave",
-    "solarized": "solarized",
-    "solarized-dark": "solarized-dark",
-    "monokai": "monokai"
-}
 
-THEMES = [*THEMES_MAP.keys()]
-
-# Hack: When the user drags some of the columns, then the class attribute contains "dragging" also.
-CSS_CLASS_MAP = {v: k for k, v in THEMES_MAP.items()}
-DEFAULT_CSS_CLASS = THEMES_MAP[DEFAULT_THEME]
+THEMES = [
+    'material', 'material-dark', 'monokai', 'solarized', 'solarized-dark', 'vaporwave'
+]
 
 class Plugin(Enum):
     """The plugins (grids/charts) available in Perspective.  Pass these into
@@ -263,7 +251,7 @@ def deconstruct_pandas(data, kwargs=None):
     return data, kwargs
 
 
-class Perspective(PaneBase, ReactiveData):
+class Perspective(ModelPane, ReactiveData):
     """
     The `Perspective` pane provides an interactive visualization component for
     large, real-time datasets built on the Perspective project.
@@ -275,23 +263,17 @@ class Perspective(PaneBase, ReactiveData):
     >>> Perspective(df, plugin='hypergrid', theme='material-dark')
     """
 
-    aggregates = param.Dict(None, doc="""
+    aggregates = param.Dict(default=None, doc="""
       How to aggregate. For example {"x": "distinct count"}""")
 
     columns = param.List(default=None, doc="""
         A list of source columns to show as columns. For example ["x", "y"]""")
 
-    computed_columns = param.List(default=None, precedence=-1, doc="""
-      Deprecated alias for expressions.""")
-
     expressions = param.List(default=None, doc="""
       A list of expressions computing new columns from existing columns.
       For example [""x"+"index""]""")
 
-    column_pivots = param.List(None, precedence=-1, doc="""
-      Deprecated alias of split_by.""")
-
-    split_by = param.List(None, doc="""
+    split_by = param.List(default=None, doc="""
       A list of source columns to pivot by. For example ["x", "y"]""")
 
     filters = param.List(default=None, doc="""
@@ -306,9 +288,6 @@ class Perspective(PaneBase, ReactiveData):
     group_by = param.List(default=None, doc="""
       A list of source columns to group by. For example ["x", "y"]""")
 
-    row_pivots = param.List(default=None, precedence=-1, doc="""
-      Deprecated alias of group_by.""")
-
     selectable = param.Boolean(default=True, allow_None=True, doc="""
       Whether items are selectable.""")
 
@@ -324,35 +303,24 @@ class Perspective(PaneBase, ReactiveData):
     toggle_config = param.Boolean(default=True, doc="""
       Whether to show the config menu.""")
 
-    theme = param.ObjectSelector(default=DEFAULT_THEME, objects=THEMES, doc="""
+    theme = param.ObjectSelector(default='material', objects=THEMES, doc="""
       The style of the PerspectiveViewer. For example material-dark""")
 
     priority: ClassVar[float | bool | None] = None
 
+    _bokeh_model: ClassVar[Type[Model] | None] = None
+
     _data_params: ClassVar[List[str]] = ['object']
 
-    _rerender_params: ClassVar[List[str]] = ['object']
-
     _rename: ClassVar[Mapping[str, str | None]] = {
-        'computed_columns': None,
-        'row_pivots': None,
-        'column_pivots': None,
-        'selection': None,
+        'selection': None
     }
 
     _updates: ClassVar[bool] = True
 
-    _deprecations = {
-        'computed_columns': 'expressions',
-        'column_pivots': 'split_by',
-        'row_pivots': 'group_by'
-    }
-
-    def __init__(self, object=None, **params):
-        super().__init__(object=object, **params)
-        self.param.watch(self._deprecated_warning, ['computed_columns', 'column_pivots', 'row_pivots'])
-        ps = [deprecation for deprecation in self._deprecations if deprecation in params]
-        self.param.trigger(*ps)
+    _stylesheets: ClassVar[List[str]] = [
+        f'{CDN_DIST}css/perspective-datatable.css'
+    ]
 
     @classmethod
     def applies(cls, object):
@@ -385,23 +353,24 @@ class Perspective(PaneBase, ReactiveData):
                              "converted to strings.")
         return df, {str(k): v for k, v in data.items()}
 
-    def _deprecated_warning(self, *events):
-        updates = {}
-        for event in events:
-            renamed = self._deprecations[event.name]
-            deprecated("1.0", event.name, renamed)
-            updates[renamed] = event.new
-        self.param.update(**updates)
-
     def _filter_properties(self, properties):
         ignored = list(Viewable.param)
         return [p for p in properties if p not in ignored]
 
-    def _init_params(self):
-        props = super()._init_params()
-        props['source'] = ColumnDataSource(data=self._data)
+    def _get_properties(self, doc, source=None):
+        props = super()._get_properties(doc)
+        del props['object']
+        if props.get('toggle_config'):
+            props['height'] = self.height or 300
+        else:
+            props['height'] = self.height or 150
+        if source is None:
+            source = ColumnDataSource(data=self._data)
+        else:
+            source.data = self._data
+        props['source'] = source
         props['schema'] = schema = {}
-        for col, array in self._data.items():
+        for col, array in source.data.items():
             if not isinstance(array, np.ndarray):
                 array = np.asarray(array)
             kind = array.dtype.kind.lower()
@@ -434,18 +403,31 @@ class Perspective(PaneBase, ReactiveData):
                     schema[col] = 'string'
         return props
 
-    def _process_param_change(self, msg):
-        msg = super()._process_param_change(msg)
+    def _get_theme(self, theme, resources=None):
+        from ..models.perspective import THEME_URL
+        theme_url = f'{THEME_URL}{theme}.css'
+        if self._bokeh_model is not None:
+            self._bokeh_model.__css_raw__ = self._bokeh_model.__css_raw__[:3] + [theme_url]
+        return theme_url
+
+    def _process_param_change(self, params):
+        if 'stylesheets' in params or 'theme' in params:
+            self._get_theme(params.get('theme', self.theme))
+            css = getattr(self._bokeh_model, '__css__', [])
+            params['stylesheets'] = [
+                ImportedStyleSheet(url=ss) for ss in css
+            ] + params.get('stylesheets', self.stylesheets)
+        props = super()._process_param_change(params)
         for p in ('columns', 'group_by', 'split_by'):
-            if msg.get(p):
-                msg[p] = [None if col is None else str(col) for col in msg[p]]
-        if msg.get('sort'):
-            msg['sort'] = [[str(col), *args] for col, *args in msg['sort']]
-        if msg.get('filters'):
-            msg['filters'] = [[str(col), *args] for col, *args in msg['filters']]
-        if msg.get('aggregates'):
-            msg['aggregates'] = {str(col): agg for col, agg in msg['aggregates'].items()}
-        return msg
+            if props.get(p):
+                props[p] = [None if col is None else str(col) for col in props[p]]
+        if props.get('sort'):
+            props['sort'] = [[str(col), *args] for col, *args in props['sort']]
+        if props.get('filters'):
+            props['filters'] = [[str(col), *args] for col, *args in props['filters']]
+        if props.get('aggregates'):
+            props['aggregates'] = {str(col): agg for col, agg in props['aggregates'].items()}
+        return props
 
     def _as_digit(self, col):
         if self._processed is None or col in self._processed or col is None:
@@ -460,12 +442,6 @@ class Perspective(PaneBase, ReactiveData):
             if prop not in msg:
                 continue
             msg[prop] = [self._as_digit(col) for col in msg[prop]]
-            if prop == 'group_by':
-                msg['row_pivots'] = msg['group_by']
-            if prop == 'split_by':
-                msg['column_pivots'] = msg['split_by']
-        if 'expressions' in msg:
-            msg['computed_columns'] = msg['expressions']
         if msg.get('sort'):
             msg['sort'] = [[self._as_digit(col), *args] for col, *args in msg['sort']]
         if msg.get('filters'):
@@ -478,19 +454,10 @@ class Perspective(PaneBase, ReactiveData):
         self, doc: Document, root: Optional[Model] = None,
         parent: Optional[Model] = None, comm: Optional[Comm] = None
     ) -> Model:
-        Perspective = lazy_load('panel.models.perspective', 'Perspective', isinstance(comm, JupyterComm), root)
-        properties = self._process_param_change(self._init_params())
-        if properties.get('toggle_config'):
-            properties['height'] = self.height or 300
-        else:
-            properties['height'] = self.height or 150
-        model = Perspective(**properties)
-        if root is None:
-            root = model
-        synced = list(set([p for p in self.param if (self.param[p].precedence or 0) > -1]) ^ (set(PaneBase.param) | set(ReactiveData.param)))
-        self._link_props(model, synced, doc, root, comm)
-        self._models[root.ref['id']] = (model, parent)
-        return model
+        self._bokeh_model = lazy_load(
+            'panel.models.perspective', 'Perspective', isinstance(comm, JupyterComm), root
+        )
+        return super()._get_model(doc, root, parent, comm)
 
     def _update(self, ref: str, model: Model) -> None:
-        pass
+        model.update(**self._get_properties(model.document, source=model.source))
