@@ -48,6 +48,20 @@ def _isin(obj, attr):
     else:
         return hasattr(obj, attr)
 
+def _get_type(spec, version):
+    if version >= 5:
+        if isinstance(spec, dict):
+            return spec.get('select', {}).get('type', 'interval')
+        elif isinstance(spec.select, dict):
+            return spec.select.get('type', 'interval')
+        else:
+            return getattr(spec.select, 'type', 'interval')
+    else:
+        if isinstance(spec, dict):
+            return spec.get('type', 'interval')
+        else:
+            return getattr(spec, 'type', 'interval')
+
 def _get_type(spec, version):
     if version >= 5:
         if isinstance(spec, dict):
