@@ -1,14 +1,14 @@
-import sys
-
 import pytest
 
+try:
+    from playwright.sync_api import expect
+except ImportError:
+    pytestmark = pytest.mark.skip('playwright not available')
+
 from panel.tests.util import wait_until
 
 pytestmark = pytest.mark.jupyter
 
-not_windows = pytest.mark.skipif(sys.platform=='win32', reason="Does not work on Windows")
-
-@not_windows
 @pytest.mark.flaky(max_runs=3)
 def test_jupyter_server(page, jupyter_preview):
     page.goto(f"{jupyter_preview}/app.py", timeout=30000)
@@ -23,7 +23,6 @@ def test_jupyter_server(page, jupyter_preview):
 
     wait_until(lambda: page.text_content('pre') == '2', page)
 
-@not_windows
 @pytest.mark.flaky(max_runs=3)
 def test_jupyter_server_custom_resources(page, jupyter_preview):
     page.goto(f"{jupyter_preview}/app.py", timeout=30000)
@@ -31,7 +30,6 @@ def test_jupyter_server_custom_resources(page, jupyter_preview):
     assert page.locator('.bk-Row').evaluate("""(element) =>
         window.getComputedStyle(element).getPropertyValue('background-color')""") == 'rgb(128, 0, 128)'
 
-@not_windows
 @pytest.mark.flaky(max_runs=3)
 def test_jupyter_server_kernel_error(page, jupyter_preview):
     page.goto(f"{jupyter_preview}/app.py?kernel=blah", timeout=30000)
@@ -45,3 +43,9 @@ def test_jupyter_server_kernel_error(page, jupyter_preview):
     page.click('button')
 
     wait_until(lambda: page.text_content('pre') == '1', page)
+
+@pytest.mark.flaky(max_runs=3)
+def test_jupyter_server_session_arg_theme(page, jupyter_preview):
+    page.goto(f"{jupyter_preview}/app.py?theme=dark", timeout=30000)
+
+    expect(page.locator('body')).to_have_css('color', 'rgb(0, 0, 0)')
