@@ -1375,6 +1375,21 @@ def test_tabulator_constant_list_filter_client_side(document, comm):
     }, index=[2, 4])
     pd.testing.assert_frame_equal(table._processed, expected)
 
+def test_tabulator_constant_single_element_list_filter_client_side(document, comm):
+    df = makeMixedDataFrame()
+    table = Tabulator(df)
+
+    table.filters = [{'field': 'C', 'type': 'in', 'value': ['foo3']}]
+
+    expected = pd.DataFrame({
+        'A': np.array([2.]),
+        'B': np.array([0.]),
+        'C': np.array(['foo3']),
+        'D': np.array(['2009-01-05T00:00:00.000000000'],
+                      dtype='datetime64[ns]')
+    }, index=[2])
+    pd.testing.assert_frame_equal(table._processed, expected)
+
 def test_tabulator_keywords_filter_client_side(document, comm):
     df = makeMixedDataFrame()
     table = Tabulator(df)
